@@ -20,11 +20,11 @@ def url_encode(key):
     if not key:
         return ""
     encode_key = parse.quote(utils.get_utf8_value(key))
-    if '%20' in encode_key:
-        encode_key = encode_key.replace('%20', '+')
-
-    if '%2A' in encode_key:
-        encode_key = encode_key.replace('%2A', '*')
+    # if '%20' in encode_key:
+    #     encode_key = encode_key.replace('%20', '+')
+    #
+    # if '%2A' in encode_key:
+    #     encode_key = encode_key.replace('%2A', '*')
 
     if '%7E' in encode_key:
         encode_key = encode_key.replace('%7E', '~')
@@ -60,7 +60,8 @@ def encode_params(query_args):
         if v:
             buf_list.append("%s=%s" % (k, v))
         else:
-            buf_list.append("%s" % k)
+            # 与v2签名不同，v4签名中，参数值为空时，也需要加上=号，以通过kop鉴权
+            buf_list.append("%s=" % k)
     return "&".join(buf_list)
 
 # Key derivation functions. See:
