@@ -17,10 +17,12 @@ from ks3.share_encryption import ShareCryptor
 from ks3.xmlParsers.bucketAccessMonitor import BucketAccessMonitor
 from ks3.xmlParsers.bucketCors import BucketCors
 from ks3.xmlParsers.bucketCrossReplicate import BucketCrossReplicate
+from ks3.xmlParsers.bucketDataRedundancySwitch import BucketDataRedundancySwitch
 from ks3.xmlParsers.bucketEncryption import BucketEncryption
 from ks3.xmlParsers.bucketLifecycle import BucketLifecycle
 from ks3.tagging import Tagging
 from ks3.xmlParsers.bucketQos import BucketQos
+from ks3.xmlParsers.bucketTransferAcceleration import BucketTransferAcceleration
 from ks3.xmlParsers.requesterQos import RequesterQos
 
 try:
@@ -1669,6 +1671,61 @@ class Bucket(object):
         else:
             raise S3ResponseError(response.status, response.reason, body)
 
+    def set_bucket_transfer_acceleration(self, enabled):
+        bta = BucketTransferAcceleration(enabled=enabled)
+        bta_xml = bta.to_xml()
+        if not isinstance(bta_xml, bytes):
+            bta_xml = bta_xml.encode('utf-8')
+        md5 = ks3.utils.compute_base64_md5_digest(bta_xml)
+        headers = {'Content-MD5': md5, 'Content-Type': 'application/xml'}
+        response = self.connection.make_request('PUT', self.name, data=bta_xml, query_args='transferAcceleration',
+                                                headers=headers)
+        body = response.read()
+        if response.status == 200:
+            return ResponseResult(None, status=response.status, reason=response.reason,
+                                  headers=response.headers)
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
+    def get_bucket_transfer_acceleration(self):
+        response = self.connection.make_request('GET', self.name, query_args='transferAcceleration')
+        body = response.read()
+        if response.status == 200:
+            bta = BucketTransferAcceleration(status=response.status, reason=response.reason, headers=response.headers,
+                                             raw_body=body)
+            h = handler.XmlHandler(bta, self)
+            if not isinstance(body, bytes):
+                body = body.encode('utf-8')
+            xml.sax.parseString(body, h)
+            return bta
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
+    def set_bucket_data_redundancy_switch(self, data_redundancy_type=None):
+        headers = {'x-kss-data-redundancy-type': data_redundancy_type}
+
+        response = self.connection.make_request('PUT', self.name, headers=headers, query_args='dataRedundancySwitch')
+        body = response.read()
+        if response.status == 200:
+            return ResponseResult(None, status=response.status, reason=response.reason,
+                                  headers=response.headers)
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
+    def get_bucket_data_redundancy_switch(self):
+        response = self.connection.make_request('GET', self.name, query_args='dataRedundancySwitch')
+        body = response.read()
+        if response.status == 200:
+            bdrs = BucketDataRedundancySwitch(status=response.status, reason=response.reason, headers=response.headers,
+                                             raw_body=body)
+            h = handler.XmlHandler(bdrs, self)
+            if not isinstance(body, bytes):
+                body = body.encode('utf-8')
+            xml.sax.parseString(body, h)
+            return bdrs
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
 
 class BucketLocation(object):
     def __init__(self, *args, **kwargs):
