@@ -8,6 +8,7 @@ import xml.sax
 
 import requests
 
+import ks3
 from ks3 import auth
 from ks3 import handler
 from ks3 import utils
@@ -20,6 +21,7 @@ from ks3.provider import Provider
 from ks3.responseResult import ResponseResult
 from ks3.resultset import ResultSet
 from ks3.utils import Ks3DnsResolver, RetryPolicy
+from ks3.xmlParsers.VpcAccessBlock import VpcAccessBlock
 
 logger = logging.getLogger(__name__)
 
@@ -270,6 +272,43 @@ class Connection(object):
 
         return resp
 
+    def set_vpc_access_block(self, vpc_access_block):
+        vab_xml = vpc_access_block.to_xml()
+        if not isinstance(vab_xml, bytes):
+            vab_xml = vab_xml.encode('utf-8')
+        md5 = ks3.utils.compute_base64_md5_digest(vab_xml)
+        headers = {'Content-MD5': md5, 'Content-Type': 'application/xml'}
+        response = self.make_request('PUT', data=vab_xml, headers=headers, query_args='VpcAccessBlock')
+        body = response.read()
+        if response.status == 200:
+            return ResponseResult(None, status=response.status, reason=response.reason,
+                                  headers=response.headers)
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
+    def get_vpc_access_block(self):
+        response = self.make_request('GET', query_args='VpcAccessBlock')
+        body = response.read()
+        if response.status == 200:
+            bta = VpcAccessBlock(status=response.status, reason=response.reason, headers=response.headers,
+                                             raw_body=body)
+            h = handler.XmlHandler(bta, self)
+            if not isinstance(body, bytes):
+                body = body.encode('utf-8')
+            xml.sax.parseString(body, h)
+            return bta
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
+    def delete_vpc_access_block(self):
+        response = self.make_request('DELETE', query_args='VpcAccessBlock')
+        body = response.read()
+        if response.status == 204:
+            return ResponseResult(None, status=response.status, reason=response.reason,
+                                  headers=response.headers)
+        else:
+            raise S3ResponseError(response.status, response.reason, body)
+
     def get_all_buckets(self, headers=None, project_ids=None,
                         region=None, prefix=None, visit_type=None, storage_type=None):
         query_args = {}
@@ -334,7 +373,7 @@ class Connection(object):
             raise S3ResponseError(response.status, response.reason, body)
 
     def create_bucket(self, bucket_name, headers=None, project_id=None,
-                      location=None, policy=None):
+                      location=None, policy=None, data_redundancy_type=None):
         check_lowercase_bucketname(bucket_name)
 
         if policy:
@@ -342,11 +381,16 @@ class Connection(object):
                 headers[self.provider.acl_header] = policy
             else:
                 headers = {self.provider.acl_header: policy}
-        if location is None:
-            data = ''
+
+        data = None
+        if location is not None:
+            data = '<LocationConstraint>%s</LocationConstraint>'.format(location)
+        if data_redundancy_type is not None:
+            data = '<DataRedundancyType>%s</DataRedundancyType>'.format(data_redundancy_type)
+        if data is not None:
+            data = '<CreateBucketConfiguration xmlns="http://s3.amazonaws.com/doc/2006-03-01/">%s</CreateBucketConfiguration>'.format(data)
         else:
-            data = '<CreateBucketConfiguration xmlns="http://s3.amazonaws.com/doc/2006-03-01/"><LocationConstraint>' + \
-                   location + '</LocationConstraint></CreateBucketConfiguration>'
+            data = ''
 
         query_args = {}
         if project_id is not None:
