@@ -36,6 +36,11 @@ RESTORE_HEADER_KEY = 'restore-header'
 TAGGING_COUNT_HEADER_KEY = 'tagging-count-header'
 OBJECT_TYPE_HEADER_KEY = 'object-type-header'
 APPEND_NEXT_POSITION_HEADER_KEY = 'append-next-position-header'
+CHECKSUM_CRC64ECMA_HEADER_KEY = 'checksum-crc64ecma-header'
+RETENTION_OVERWRITE_HEADER_KEY = 'retention-overwrite'
+RETENTION_ID_HEADER_KEY = 'retention-id'
+POLICY_HEADER_KEY = 'policy'
+MIGRATION_SOURCE_HEADER_KEY = 'migration-source'
 
 STORAGE_COPY_ERROR = 'StorageCopyError'
 STORAGE_CREATE_ERROR = 'StorageCreateError'
@@ -118,7 +123,12 @@ class Provider(object):
             RESTORE_HEADER_KEY: KSS_HEADER_PREFIX + 'restore',
             TAGGING_COUNT_HEADER_KEY: KSS_HEADER_PREFIX + 'tagging-count',
             OBJECT_TYPE_HEADER_KEY: KSS_HEADER_PREFIX + 'object-type',
-            APPEND_NEXT_POSITION_HEADER_KEY: KSS_HEADER_PREFIX + 'append-next-position'
+            APPEND_NEXT_POSITION_HEADER_KEY: KSS_HEADER_PREFIX + 'append-next-position',
+            CHECKSUM_CRC64ECMA_HEADER_KEY: KSS_HEADER_PREFIX + 'checksum-crc64ecma',
+            RETENTION_OVERWRITE_HEADER_KEY: KSS_HEADER_PREFIX + 'retention-overwrite',
+            RETENTION_ID_HEADER_KEY: KSS_HEADER_PREFIX + 'retention-id',
+            MIGRATION_SOURCE_HEADER_KEY: KSS_HEADER_PREFIX + 'migration-source',
+            POLICY_HEADER_KEY: KSS_HEADER_PREFIX + 'policy'
         },
         'aws': {
             HEADER_PREFIX_KEY: AWS_HEADER_PREFIX,
@@ -450,7 +460,11 @@ class Provider(object):
         self.tagging_count_header = header_info_map[TAGGING_COUNT_HEADER_KEY]
         self.object_type_header = header_info_map[OBJECT_TYPE_HEADER_KEY]
         self.append_next_position_header = header_info_map[APPEND_NEXT_POSITION_HEADER_KEY]
-
+        self.checksum_crc64ecma_header = header_info_map[CHECKSUM_CRC64ECMA_HEADER_KEY]
+        self.retention_overwrite_header = header_info_map[RETENTION_OVERWRITE_HEADER_KEY]
+        self.retention_id_header = header_info_map[RETENTION_ID_HEADER_KEY]
+        self.migration_source_header = header_info_map[MIGRATION_SOURCE_HEADER_KEY]
+        self.policy_header = header_info_map[POLICY_HEADER_KEY]
 
     def configure_errors(self):
         error_map = self.ErrorMap[self.name]
