@@ -16,11 +16,17 @@ class BucketMirror(object):
 
     def __getitem__(self, item):
         if item == 'async_mirror_rule':
-            return dict(getattr(self, item))
+            rule = dict(getattr(self, item))
+            if rule.get('mirror_type') is None:
+               rule.pop('mirror_type')
+            return rule
         if item == 'sync_mirror_rules':
             rules_dict = []
             for value in getattr(self, item):
-                rules_dict.append(dict(value))
+                rule = dict(value)
+                if rule.get('mirror_type') is None:
+                    rule.pop('mirror_type')
+                rules_dict.append(rule)
             return rules_dict
         return getattr(self, item)
 
@@ -31,21 +37,22 @@ class SavingSetting(object):
 
 
 class AsyncMirrorRule(object):
-    def __init__(self, mirror_urls=None, saving_setting=None):
+    def __init__(self, mirror_urls=None, saving_setting=None, mirror_type=None):
         if mirror_urls is None:
             mirror_urls = []
         self.mirror_urls = mirror_urls
         self.saving_setting = saving_setting
+        self.mirror_type = mirror_type
 
     @classmethod
-    def rule_with_acl(cls, mirror_urls=None, saving_setting_acl=None):
+    def rule_with_acl(cls, mirror_urls=None, saving_setting_acl=None, mirror_type=None):
         if mirror_urls is None:
             mirror_urls = []
         saving_setting = SavingSetting(acl=saving_setting_acl)
-        return cls(mirror_urls=mirror_urls, saving_setting=saving_setting)
+        return cls(mirror_urls=mirror_urls, saving_setting=saving_setting, mirror_type=mirror_type)
 
     def keys(self):
-        return ('mirror_urls', 'saving_setting')
+        return 'mirror_urls', 'saving_setting', 'mirror_type'
 
     def __getitem__(self, item):
         if item == 'saving_setting':
@@ -54,20 +61,21 @@ class AsyncMirrorRule(object):
 
 
 class SyncMirrorRules(object):
-    def __init__(self, match_condition=None, mirror_url=None, mirror_request_setting=None, saving_setting=None):
+    def __init__(self, match_condition=None, mirror_url=None, mirror_request_setting=None, saving_setting=None, mirror_type=None):
         self.saving_setting = saving_setting
         self.mirror_request_setting = mirror_request_setting
         self.mirror_url = mirror_url
         self.match_condition = match_condition
+        self.mirror_type = mirror_type
 
     @classmethod
-    def rules_with_prefix_acl(cls, key_prefixes=None, mirror_url=None, mirror_request_setting=None, saving_setting_acl=None):
+    def rules_with_prefix_acl(cls, key_prefixes=None, mirror_url=None, mirror_request_setting=None, saving_setting_acl=None, mirror_type=None):
         saving_setting = SavingSetting(acl=saving_setting_acl)
         match_condition = MatchCondition(key_prefixes=key_prefixes)
-        return cls(match_condition=match_condition, mirror_url=mirror_url, mirror_request_setting=mirror_request_setting, saving_setting=saving_setting)
+        return cls(match_condition=match_condition, mirror_url=mirror_url, mirror_request_setting=mirror_request_setting, saving_setting=saving_setting, mirror_type=mirror_type)
 
     def keys(self):
-        return ('saving_setting', 'mirror_request_setting', 'mirror_url', 'match_condition')
+        return 'saving_setting', 'mirror_request_setting', 'mirror_url', 'match_condition', 'mirror_type'
 
     def __getitem__(self, item):
         if item == 'mirror_request_setting':
