@@ -1,7 +1,12 @@
+from ks3.responseResult import ResponseMetadata
+
+
 class BucketVersioningConfig(object):
-    def __init__(self, status=None):
+    def __init__(self, status=None, *args, **kwargs):
         self.status = status
 
+        self.response_metadata = ResponseMetadata(**kwargs)
+
     def __repr__(self):
         return "status " + self.status
 
